@@ -1,7 +1,7 @@
 """
 Type annotations for ebs service client.
 
-[Open documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_ebs/client.html)
+[Open documentation](./client.md)
 
 Usage::
 
@@ -17,7 +17,7 @@ from typing import IO, Any, Dict, List, Type, Union
 
 from botocore.client import ClientMeta
 
-from mypy_boto3_ebs.type_defs import (
+from .type_defs import (
     CompleteSnapshotResponseTypeDef,
     GetSnapshotBlockResponseTypeDef,
     ListChangedBlocksResponseTypeDef,
@@ -58,8 +58,8 @@ class Exceptions:
 
 class EBSClient:
     """
-    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.67/reference/services/ebs.html#EBS.Client)
-    [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_ebs/client.html)
+    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.70/reference/services/ebs.html#EBS.Client)
+    [Show boto3-stubs documentation](./client.md)
     """
 
     meta: ClientMeta
@@ -67,8 +67,8 @@ class EBSClient:
 
     def can_paginate(self, operation_name: str) -> bool:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.67/reference/services/ebs.html#EBS.Client.can_paginate)
-        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_ebs/client.html#can-paginate)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.70/reference/services/ebs.html#EBS.Client.can_paginate)
+        [Show boto3-stubs documentation](./client.md#can-paginate)
         """
 
     def complete_snapshot(
@@ -80,8 +80,8 @@ class EBSClient:
         ChecksumAggregationMethod: Literal["LINEAR"] = None,
     ) -> CompleteSnapshotResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.67/reference/services/ebs.html#EBS.Client.complete_snapshot)
-        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_ebs/client.html#complete-snapshot)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.70/reference/services/ebs.html#EBS.Client.complete_snapshot)
+        [Show boto3-stubs documentation](./client.md#complete-snapshot)
         """
 
     def generate_presigned_url(
@@ -92,16 +92,16 @@ class EBSClient:
         HttpMethod: str = None,
     ) -> str:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.67/reference/services/ebs.html#EBS.Client.generate_presigned_url)
-        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_ebs/client.html#generate-presigned-url)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.70/reference/services/ebs.html#EBS.Client.generate_presigned_url)
+        [Show boto3-stubs documentation](./client.md#generate-presigned-url)
         """
 
     def get_snapshot_block(
         self, SnapshotId: str, BlockIndex: int, BlockToken: str
     ) -> GetSnapshotBlockResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.67/reference/services/ebs.html#EBS.Client.get_snapshot_block)
-        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_ebs/client.html#get-snapshot-block)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.70/reference/services/ebs.html#EBS.Client.get_snapshot_block)
+        [Show boto3-stubs documentation](./client.md#get-snapshot-block)
         """
 
     def list_changed_blocks(
@@ -113,8 +113,8 @@ class EBSClient:
         StartingBlockIndex: int = None,
     ) -> ListChangedBlocksResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.67/reference/services/ebs.html#EBS.Client.list_changed_blocks)
-        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_ebs/client.html#list-changed-blocks)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.70/reference/services/ebs.html#EBS.Client.list_changed_blocks)
+        [Show boto3-stubs documentation](./client.md#list-changed-blocks)
         """
 
     def list_snapshot_blocks(
@@ -125,8 +125,8 @@ class EBSClient:
         StartingBlockIndex: int = None,
     ) -> ListSnapshotBlocksResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.67/reference/services/ebs.html#EBS.Client.list_snapshot_blocks)
-        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_ebs/client.html#list-snapshot-blocks)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.70/reference/services/ebs.html#EBS.Client.list_snapshot_blocks)
+        [Show boto3-stubs documentation](./client.md#list-snapshot-blocks)
         """
 
     def put_snapshot_block(
@@ -140,8 +140,8 @@ class EBSClient:
         Progress: int = None,
     ) -> PutSnapshotBlockResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.67/reference/services/ebs.html#EBS.Client.put_snapshot_block)
-        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_ebs/client.html#put-snapshot-block)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.70/reference/services/ebs.html#EBS.Client.put_snapshot_block)
+        [Show boto3-stubs documentation](./client.md#put-snapshot-block)
         """
 
     def start_snapshot(
@@ -156,6 +156,6 @@ class EBSClient:
         Timeout: int = None,
     ) -> StartSnapshotResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.67/reference/services/ebs.html#EBS.Client.start_snapshot)
-        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_ebs/client.html#start-snapshot)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.70/reference/services/ebs.html#EBS.Client.start_snapshot)
+        [Show boto3-stubs documentation](./client.md#start-snapshot)
         """
